==> redux-0.5.0.tgz: package/lib/addons/container.js <==
'use strict';

var _createClass = require('babel-runtime/helpers/create-class')['default'];

var _classCallCheck = require('babel-runtime/helpers/class-call-check')['default'];

var _extends = require('babel-runtime/helpers/extends')['default'];

var _Object$defineProperty = require('babel-runtime/core-js/object/define-property')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

_Object$defineProperty(exports, '__esModule', {
  value: true
});

exports['default'] = container;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _Container = require('../Container');

var _Container2 = _interopRequireDefault(_Container);

var _getDisplayName = require('./getDisplayName');

var _getDisplayName2 = _interopRequireDefault(_getDisplayName);

function container(_ref) {
  var actions = _ref.actions;
  var stores = _ref.stores;

  return function (DecoratedComponent) {
    return (function () {
      function ReduxContainerDecorator() {
        _classCallCheck(this, ReduxContainerDecorator);
      }

      _createClass(ReduxContainerDecorator, [{
        key: 'render',
        value: function render() {
          var _this = this;

          return _react2['default'].createElement(
            _Container2['default'],
            { actions: actions, stores: stores },
            function (props) {
              return _react2['default'].createElement(DecoratedComponent, _extends({}, _this.props, props));
            }
          );
        }
      }], [{
        key: 'displayName',
        value: 'ReduxContainer(' + (0, _getDisplayName2['default'])(DecoratedComponent) + ')',
        enumerable: true
      }]);

      return ReduxContainerDecorator;
    })();
  };
}

module.exports = exports['default'];

==> redux-0.6.1.tgz: package/lib/addons/container.js <==
'use strict';

var _extends = require('babel-runtime/helpers/extends')['default'];

var _createClass = require('babel-runtime/helpers/create-class')['default'];

var _classCallCheck = require('babel-runtime/helpers/class-call-check')['default'];

var _Object$defineProperty = require('babel-runtime/core-js/object/define-property')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

_Object$defineProperty(exports, '__esModule', {
  value: true
});

exports['default'] = container;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _Container = require('../Container');

var _Container2 = _interopRequireDefault(_Container);

var _getDisplayName = require('./getDisplayName');

var _getDisplayName2 = _interopRequireDefault(_getDisplayName);

function defaultTransformProps(_ref) {
  var state = _ref.state;
  var actions = _ref.actions;

  return _extends({}, state, actions);
}

function container(_ref2) {
  var actions = _ref2.actions;
  var stores = _ref2.stores;
  var transformProps = arguments[1] === undefined ? defaultTransformProps : arguments[1];

  return function (DecoratedComponent) {
    return (function () {
      function ReduxContainerDecorator() {
        _classCallCheck(this, ReduxContainerDecorator);
      }

      _createClass(ReduxContainerDecorator, [{
        key: 'render',
        value: function render() {
          var _this = this;

          return _react2['default'].createElement(
            _Container2['default'],
            { actions: actions, stores: stores },
            function (props) {
              return _react2['default'].createElement(DecoratedComponent, _extends({}, _this.props, transformProps(props)));
            }
          );
        }
      }], [{
        key: 'displayName',
        value: 'ReduxContainer(' + (0, _getDisplayName2['default'])(DecoratedComponent) + ')',
        enumerable: true
      }]);

      return ReduxContainerDecorator;
    })();
  };
}

module.exports = exports['default'];
